@@ -3,7 +3,7 @@
 
 import json
 import logging
-from collections import Mapping, Sequence
+from collections.abc import Mapping, Sequence
 
 import requests
 import websockets
